All of lore.kernel.org
 help / color / mirror / Atom feed
* [yocto-autobuilder2][PATCH] schedulers: add meta-webosose scheduled build for scarthgap
@ 2025-04-29  2:16 hieu2.nguyen
  2025-04-29  6:37 ` [yocto-patches] " Mathieu Dubois-Briand
  2025-05-14 10:00 ` [yocto-patches] " Richard Purdie
  0 siblings, 2 replies; 6+ messages in thread
From: hieu2.nguyen @ 2025-04-29  2:16 UTC (permalink / raw)
  To: yocto-patches; +Cc: martin.jansa, Hieu Van Nguyen

From: Hieu Van Nguyen <hieu2.nguyen@lge.com>

Support to build meta-webosose for both of kirkstone and scarthgap
branches.

Signed-off-by: Hieu Van Nguyen <hieu2.nguyen@lge.com>
---
 schedulers.py | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/schedulers.py b/schedulers.py
index fd2cad6..1fead60 100644
--- a/schedulers.py
+++ b/schedulers.py
@@ -642,7 +642,10 @@ schedulers.append(sched.AnyBranchScheduler(name="bitbake-docs-changed",
             properties=repos_dict_for_scheduler("docs"),
             builderNames=["docs"]))
 
 # Run meta-webosose for kirkstone once a week on weekends (2am on Friday)
 schedulers.append(sched.Nightly(name='nightly-meta-webosose', branch='kirkstone', properties=parent_default_props('meta-webosose', 'kirkstone'),
                                 codebases = {'' : {'branch' : 'kirkstone'}},
                                 builderNames=['meta-webosose'], hour=2, minute=0, dayOfWeek=4))
+schedulers.append(sched.Nightly(name='nightly-meta-webosose', branch='scarthgap', properties=parent_default_props('meta-webosose', 'scarthgap'),
+                                codebases = {'' : {'branch' : 'scarthgap'}},
+                                builderNames=['meta-webosose'], hour=2, minute=0, dayOfWeek=4))
@@ -642,7 +642,10 @@ schedulers.append(sched.AnyBranchScheduler(name="bitbake-docs-changed",
             builderNames=["docs"]))
 
-# Run meta-webosose for kirkstone once a week on weekends (2am on Friday)
+# Run meta-webosose for kirkstone and scarthgap once a week on weekends (2am on Friday)
 schedulers.append(sched.Nightly(name='nightly-meta-webosose', branch='kirkstone', properties=parent_default_props('meta-webosose', 'kirkstone'),
                                 codebases = {'' : {'branch' : 'kirkstone'}},
-- 
2.48.1



^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2025-05-14 10:00 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-04-29  2:16 [yocto-autobuilder2][PATCH] schedulers: add meta-webosose scheduled build for scarthgap hieu2.nguyen
2025-04-29  6:37 ` [yocto-patches] " Mathieu Dubois-Briand
2025-04-29  6:47   ` Martin Jansa
2025-04-29  8:35     ` Mathieu Dubois-Briand
2025-05-07 13:06       ` Hieu Van Nguyen
2025-05-14 10:00 ` [yocto-patches] " Richard Purdie

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.